@@ -2,8 +2,6 @@ import argparse
 import logging
 import os
 import types
-import zlib
-import json
 from typing import List, Text, Union, Optional, Any
 from ssl import SSLContext
 
@@ -76,7 +74,7 @@ def create_app(
     Returns:
         A new Sanic application ready to be run.
     """
-    app = Sanic("rasa_sdk", configure_logging=False, register=False)
+    app = Sanic("rasa_sdk", configure_logging=False)
 
     configure_cors(app, cors_origins)
 
@@ -92,13 +90,7 @@ def create_app(
     @app.post("/webhook")
     async def webhook(request: Request) -> HTTPResponse:
         """Webhook to retrieve action calls."""
-        if request.headers.get("Content-Encoding") == "deflate":
-            # Decompress the request data using zlib
-            decompressed_data = zlib.decompress(request.body)
-            # Load the JSON data from the decompressed request data
-            action_call = json.loads(decompressed_data)
-        else:
-            action_call = request.json
+        action_call = request.json
         if action_call is None:
             body = {"error": "Invalid body request"}
             return response.json(body, status=400)
@@ -130,15 +122,6 @@ def create_app(
         body = [{"name": k} for k in executor.actions.keys()]
         return response.json(body, status=200)
 
-    @app.exception(Exception)
-    async def exception_handler(request, exception: Exception):
-        logger.error(
-            msg=f"Exception occurred during execution of request {request}",
-            exc_info=exception,
-        )
-        body = {"error": str(exception), "request_body": request.json}
-        return response.json(body, status=500)
-
     return app
 
 
